%define upstream_name HandBrake
%define download %{_builddir}/%{upstream_name}-%{version}/download

Summary:        MPEG-AVC(H.264)/MPEG-4 converter
Name:           handbrake
Version:        1.0.7
Release:        %mkrel 1
License:        GPLv2 and LGPL and LGPLv2.1 and BSD
Group:          Video/Editors and Converters
URL:            https://handbrake.fr/
Source0:        https://download.handbrake.fr/releases/%{version}/%{upstream_name}-%{version}.tar.bz2
Source1:        https://download.handbrake.fr/handbrake/contrib/libav-12.tar.gz
Source2:        https://download.handbrake.fr/handbrake/contrib/libbluray-0.9.3.tar.bz2
Source3:        https://download.handbrake.fr/handbrake/contrib/libdvdnav-5.0.1.tar.bz2
Source4:        https://download.handbrake.fr/handbrake/contrib/libdvdread-5.0.0-6-gcb1ae87.tar.gz
Source5:        https://download.handbrake.fr/contrib/libvpx-1.5.0.tar.bz2
Source6:        https://download.handbrake.fr/contrib/x265_2.1-1.tar.gz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  m4
BuildRequires:  yasm
BuildRequires:  bzip2-devel
BuildRequires:  lame-devel
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(webkitgtk-3.0)
BuildRequires:  pkgconfig(x264)
BuildRequires:  pkgconfig(zlib)

#ARM architecture is officially not supported by HandBrake (see https://github.com/HandBrake/HandBrake/issues/538)
#We only exclude ARMv5 since the package still builds on ARMv7.
ExcludeArch: armv5tl

%description
Versatile DVD ripper and video transcoder - command line
HandBrake is a versatile, easy-to-use tool for converting DVDs and other videos
into H.264, MPEG-4, or OGG formatted media. It's particularly useful for making
videos that are compatible with portable video devices such as the Apple
iPod/iPhone.

%prep
%setup -q -n %{upstream_name}-%{version}
%{__mkdir} %download
%{__cp} -t %download %{SOURCE1}
%{__cp} -t %download %{SOURCE2}
%{__cp} -t %download %{SOURCE3}
%{__cp} -t %download %{SOURCE4}
%{__cp} -t %download %{SOURCE5}
%{__cp} -t %download %{SOURCE6}

# Copied from libvpx, in particular that avoids using neon/soft abi on armv7hl
%ifarch %{ix86}
%global vpxtarget x86-linux-gcc
%else
%ifarch	x86_64
%global	vpxtarget x86_64-linux-gcc
%else
%global vpxtarget generic-gnu
%endif
%endif

echo LIBVPX.CONFIGURE.extra += --target=%{vpxtarget} >> contrib/libvpx/module.defs

%build
# This hack was removed in the previous version of the script. It is added again on demand of Florian Hubold
# See https://bugs.mageia.org/show_bug.cgi?id=5502#c20
# On update, when someone forgets to redo the tarball of the contribs libraries, handbrake buildsystem
# will automatically download those, that is objectionable on mageia buildsystema and build should fail
# small hack, proposed by Anssi, to disable accidental automatic downloading of contrib libraries
mkdir -p disable_contrib.fetch-hack

for downloader in wget url; do
  ln -s /bin/false disable_contrib.fetch-hack/${downloader}
done
#add it to PATH so our fake downloaders get picked up from handbrake buildsystem
export PATH=$PWD/disable_contrib.fetch-hack:$PATH

# Tricky pony : the ./configure script doesn't
# know the usual params of configure2_5x
# --disable-fdk-aac option ensure that no non-free
# material is compiled with main sources
%setup_compile_flags
./configure \
        --prefix=%{_prefix} \
        --launch \
        --launch-jobs=0 \
        --verbose \
        --debug=none

%make_build -C build

%install
%make_install -C build

%find_lang ghb

desktop-file-install --vendor="" \
  --remove-category="Application" \
  --remove-key="Encoding" \
  --add-category="AudioVideo;Video;AudioVideoEditing;" \
  --add-category="X-Mageia-CrossDesktop" \
  --dir %buildroot/%_datadir/applications %buildroot/%_datadir/applications/*

%files -f ghb.lang
%doc AUTHORS* NEWS* README* THANKS*
%license COPYING
%{_bindir}/ghb
%{_bindir}/HandBrakeCLI
%{_datadir}/applications/ghb.desktop
%{_iconsdir}/hicolor/scalable/apps/hb-icon.svg


%changelog
* Sat Apr 22 2017 augier <augier> 1.0.7-1.mga6
+ Revision: 1097051
- Bump HandBrake to 1.0.7

* Sun Feb 26 2017 augier <augier> 1.0.3-2.mga6.tainted
+ Revision: 1087952
- Exclude ARMv5 from supported platforms since ARM platform is officially not supported by HandBrake

* Sun Feb 26 2017 augier <augier> 1.0.3-1.mga6.tainted
+ Revision: 1087923
- bump HandBrake to 1.0.3

* Wed Jan 11 2017 daviddavid <daviddavid> 1.0.1-2.mga6.tainted
+ Revision: 1081125
- submit to tainted/release

* Wed Jan 11 2017 daviddavid <daviddavid> 1.0.1-1.mga6.tainted
+ Revision: 1081112
- new version: 1.0.1
- switch to gstreamer 1.0
- update bundled libav, libbluray, libdvdnav, libvpx and x265
- add BRs pkgconfig(opus) and pkgconfig(jansson)
- switch BRs to pkgconfig()

  + tv <tv>
    - new release

* Sun Nov 27 2016 wally <wally> 0.10.5-3.mga6.tainted
+ Revision: 1070393
- drop unneeded freetype BR

* Sun Oct 16 2016 pterjan <pterjan> 0.10.5-2.mga6.tainted
+ Revision: 1061100
- Fix typo, I should copy/paste
- Fix typo
- Use same target for embedded libvpx that we use in libvpx package, it may fix arm build

* Sun Feb 14 2016 augier <augier> 0.10.5-1.mga6.tainted
+ Revision: 960194
- Bump HandBrake to 0.10.5
- Bump x265 sources to 1.9
- Removed --disable-fdk-aac compilation option as support for FDK-AAC is disabled by default in 0.10.5

* Mon Feb 08 2016 zezinho <zezinho> 0.10.3-1.mga6
+ Revision: 948058
- new version
- bundled x265 version is now 1.8

* Mon Jan 18 2016 luigiwalser <luigiwalser> 0.10.0-2.mga6.tainted
+ Revision: 925620
- rebuild for x264

* Wed Jan 14 2015 augier <augier> 0.10.0-1.mga5.tainted
+ Revision: 810593
+ rebuild (emptylog)

* Wed Oct 15 2014 umeabot <umeabot> 0.10-0.r6383.3.mga5.tainted
+ Revision: 750618
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.10-0.r6383.2.mga5.tainted
+ Revision: 680077
- Mageia 5 Mass Rebuild

* Sat Aug 30 2014 augier <augier> 0.10-0.r6383.1.mga5.tainted
+ Revision: 669464
- Updated sources to revision 6383
- Removed fdk-aac tarball from sources
- Updated licenses

* Fri Aug 29 2014 augier <augier> 0.10b1-0.r6348.mga5.tainted
+ Revision: 669212
- Update to version 0.10 rc1 (revision 6348)
- Reintroduce handbrake due to dropped faac, this makes all code GPLv2+

* Sun Sep 18 2011 fwang <fwang> 0.9.5-5.mga2.tainted
+ Revision: 145023
- rebuild for new libpng

* Mon Sep 05 2011 doktor5000 <doktor5000> 0.9.5-4.mga2.tainted
+ Revision: 138893
- add BuildRequires on desktop-file-utils
- adapt license information due to building with bundled faac
- really disable automatic contrib libraries download
- removed useless %%clean and %%defattr
- removed obsolete categories from desktop filename, added proper ones
- removed icon filename extension in desktop file
- added gcc hack to properly apply Mageia %%optflags
- fixed all -Wformat-security issues in faac frontend, mp4v2 and libhb
- make symlink names for CLI and GTK binary more consistent
- escape macros in comments to make rpmlint happy
- disable GUI update checks

* Mon Jul 04 2011 fwang <fwang> 0.9.5-3.mga2
+ Revision: 117908
- rebuild for new webkit

* Mon Jun 20 2011 obgr_seneca <obgr_seneca> 0.9.5-2.mga2
+ Revision: 110397
- fixed typo in file list

* Thu Jun 09 2011 obgr_seneca <obgr_seneca> 0.9.5-1.mga2
+ Revision: 102461
- added patches for libnotify and dbus-glib-1
- imported package handbrake

